<?php
/**
 * The template for displaying comments.
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Biru
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments-area">
	<?php
	if ( have_comments() ) : ?>
		<h3 class="widget-title comments-title"><span>
			<?php
				printf( // WPCS: XSS OK.
					esc_html( _nx( '1 Comment', '%1$s Comments', get_comments_number(), 'comments title', 'biru' ) ),
					number_format_i18n( get_comments_number() )
				);
			?>
		</span></h3>

		<ol class="media-list comment-list">
			<?php
				wp_list_comments( array(
					'style'      => 'ol',
					'short_ping' => true,
					'avatar_size' => 42,
					'walker' => new WP_Bootstrap_Comments_Walker(),
				) );
			?>
		<!-- .comment-list --></ol>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
			<div class="row nav-links">
				<div class="col-xs-6 nav-previous"><?php previous_comments_link( __( '<span class="ti-angle-left"></span> Older Comments', 'biru' ) ); ?></div>
				<div class="col-xs-6 text-right nav-next"><?php next_comments_link( __( 'Newer Comments <span class="ti-angle-right"></span>', 'biru' ) ); ?></div>
			<!-- .nav-links --></div>
		<!-- #comment-nav-below --></nav>
		<?php
		endif; // Check for comment navigation.

	endif; // Check for have_comments().

	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'biru' ); ?></p>
	<?php endif; ?>

	<?php
		$req = get_option( 'require_name_email' );
		$aria_req = ( $req ? " aria-required='true'" : '' );

		$args = array(
			'id_form'				=> 'commentform',
			'id_submit'				=> 'submit',
			'class_submit'			=> 'btn btn-lg btn-neowp',
			'title_reply'			=> __( 'Leave a Reply', 'biru' ),
			'title_reply_to'		=> __( 'Leave a Reply to %s', 'biru' ),
			'cancel_reply_link' 	=> __( 'Cancel Reply', 'biru' ),
			'label_submit'			=> __( 'Post Comment', 'biru' ),

			'comment_field' 		=>	'<div class="form-group comment-form-comment">' .
				'<textarea id="comment" class="form-control" name="comment" cols="45" rows="4" aria-required="true" placeholder="'. esc_attr( 'Your comment...', 'biru' ) .'">' .
				'</textarea></div>',

			'must_log_in' 			=> '<p class="alert alert-warning must-log-in">' .
				sprintf(
					__( 'You must be <a href="%s">logged in</a> to post a comment.', 'biru' ),
					wp_login_url( apply_filters( 'the_permalink', get_permalink() ) )
				) . '</p>',

			'logged_in_as' 			=> '<p class="alert alert-info logged-in-as">' .
				sprintf(
					__( 'Logged in as <a href="%1$s">%2$s</a>. <a href="%3$s" title="Log out of this account">Log out?</a>', 'biru' ),
					admin_url( 'profile.php' ),
					$user_identity,
					wp_logout_url( apply_filters( 'the_permalink', get_permalink( ) ) )
				) . '</p>',

			'comment_notes_before' 	=> '<p class="alert alert-info comment-notes">' .
				__( 'Your email address will not be published.', 'biru' ) .
				'</p>',

			'comment_notes_after' 	=> '<p class="form-allowed-tags">' .
				sprintf(
					__( 'You may use these <abbr title="HyperText Markup Language">HTML</abbr> tags and attributes: %s', 'biru' ),
					' <code>' . allowed_tags() . '</code>'
				) . '</p>',

			'fields' 				=> apply_filters( 'comment_form_default_fields', array(
				'author'			=>
					'<div class="form-group comment-form-author">' .
					'<input id="author" class="form-control" name="author" type="text" placeholder="'. esc_attr( 'Name', 'biru' ) .''. ( $req ? '*' : '' ) .'" value="' . esc_attr( $commenter['comment_author'] ) .
					'" size="30"' . $aria_req . ' /></div>',

				'email'				=>
					'<div class="form-group comment-form-email">' .
					'<input id="email" class="form-control" name="email" type="text" placeholder="'. esc_attr( 'Email', 'biru' ) .''. ( $req ? '*' : '' ) .'" value="' . esc_attr(	$commenter['comment_author_email'] ) .
					'" size="30"' . $aria_req . ' /></div>',

				'url'				=>
					'<div class="form-group comment-form-url">' .
					'<input id="url" class="form-control" name="url" type="text" placeholder="'. esc_attr( 'Website', 'biru' ) .'" value="' . esc_attr( $commenter['comment_author_url'] ) .
					'" size="30" /></div>'
				)
			),
		);
	?>

	<?php comment_form( $args ); ?>
<!-- #comments --></div>
