<?php
/**
 * Biru functions and definitions.
 *
 * @package Biru
 */

/*-----------------------------------------------------------------------------------*/
/* Set up theme defaults and registers support for various WordPress features.
/* ----------------------------------------------------------------------------------*/
if ( ! function_exists( 'biru_setup' ) ) :
function biru_setup() {
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	add_theme_support( 'post-thumbnails' );
	add_image_size( 'thumb-small', 75, 75, true );
	add_image_size( 'thumb-medium', 300, 250, true );
	add_image_size( 'thumb-large', 750, 500, true );

	load_theme_textdomain( 'biru', get_template_directory() . '/languages' );

	register_nav_menus( array(
		'main' => esc_html__( 'Main Menu', 'biru' ),
	) );
}
endif;
add_action( 'after_setup_theme', 'biru_setup' );

/*-----------------------------------------------------------------------------------*/
/* Set the content width based on the theme's design and stylesheet.
/* ----------------------------------------------------------------------------------*/
function biru_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'biru_content_width', 640 );
}
add_action( 'after_setup_theme', 'biru_content_width', 0 );

/*-----------------------------------------------------------------------------------*/
/* Register widgetized area and update sidebars with default widgets.
/* ----------------------------------------------------------------------------------*/
function biru_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'biru' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Right sidebar widgets here.', 'biru' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer #1', 'biru' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Optional sub-footer widget area.', 'biru' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer #2', 'biru' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Optional sub-footer widget area.', 'biru' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer #3', 'biru' ),
		'id'            => 'sidebar-4',
		'description'   => esc_html__( 'Optional sub-footer widget area.', 'biru' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer #4', 'biru' ),
		'id'            => 'sidebar-5',
		'description'   => esc_html__( 'Optional sub-footer widget area.', 'biru' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'biru_widgets_init' );

/*-----------------------------------------------------------------------------------*/
/* Count the number of footer sidebars to enable dynamic classes for the footer.
/* ----------------------------------------------------------------------------------*/
function biru_subfooter_widget_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'col-md-12';
			break;
		case '2':
			$class = 'col-md-6';
			break;
		case '3':
			$class = 'col-md-4';
			break;
		case '4':
			$class = 'col-md-3';
			break;
	}

	if ( $class )
		echo 'class="' . $class . ' widget-area"';
}

/*-----------------------------------------------------------------------------------*/
/* Add grid classes for the featured posts on the home page.
/* ----------------------------------------------------------------------------------*/
function biru_featured_class( $class = '', $post_id = null ) {
	global $featured;
 
	if ( $class ) {
		$class .= ' ';
	}
	if ( $featured->current_post === 0 ) {
		$class .= 'active';
		return post_class( $class, $post_id );
	} else {
		return post_class( $class, $post_id );
	}
}

/*-----------------------------------------------------------------------------------*/
/* Adds custom classes to the array of body classes.
/* ----------------------------------------------------------------------------------*/
function biru_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'biru_body_classes' );

/*-----------------------------------------------------------------------------------*/
/* Limit the excerpts characters.
/* ----------------------------------------------------------------------------------*/
function biru_limit_string($string, $limit) {
	if (strlen($string) < $limit)
		return $string;
	$reg ="/^(.{1," . $limit . "}[^\s]*).*$/s";
	return preg_replace($reg, '\\1', $string);
}

/*-----------------------------------------------------------------------------------*/
/* Display the protected posts password form.
/* ----------------------------------------------------------------------------------*/
function biru_password_form ( $form ) {
	global $post;
	$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
	$form = 
		'<p>' .
			__( 'To view this protected post, enter the password below:', 'biru' ) .
		'</p>' .
		'<form class="form-inline form-pass" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">' .
			'<div class="form-group"> ' .
				'<label class="sr-only" for="' . $label . '">' . __( 'Password', 'biru' ) . ' :</label>' .
				'<input placeholder="'. __( 'Password', 'biru' ) . '" class="form-control" name="post_password" id="' . $label . '" type="password" size="20" maxlength="20" />' .
			'</div>' .
			'<button type="submit" class="btn btn-neowp">' . esc_attr__( 'Submit', 'biru' ) . '</button>' .
		'</form>';
	return $form;
}
if ( !is_admin() ) {
    add_filter( 'the_password_form', 'biru_password_form' );
}

/*-----------------------------------------------------------------------------------*/
/*  Theme Options/Customizer.
/* ----------------------------------------------------------------------------------*/
/* Get theme options. ---------------------------------------------------------------*/
function biru_get_option( $option_name, $default = '' ) {
	$options = get_option( 'biru_option' );
	if( isset($options[$option_name]) ) {
		return $options[$option_name];
	}
	return $default; 
}

/* Display logo. --------------------------------------------------------------------*/
function biru_site_branding() {
	$header_tag = ( is_home() || is_front_page() ) ? 'h1' : 'div';
	$branding_logo = esc_url( biru_get_option( 'logo' ) );
	$branding_display = ( biru_get_option( 'display', 'site_title' ) == 'site_title' ) ? 'display-title' : 'display-logo';
	$branding_tagline = get_bloginfo( 'description' );

	echo '<div class="navbar-header site-branding">';
	echo '<' . $header_tag . ' class="navbar-brand site-title ' . $branding_display . '"><a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" rel="home">';
	if ( $branding_display === 'display-logo' ) {
		echo '<img src="' . $branding_logo . '" alt="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" />';
	} else {
		echo get_bloginfo( 'name' );
	}
	echo '</a></' . $header_tag . '>';

	if ( $branding_display === 'display-title' ) {
		if( $branding_tagline )
			echo '<div class="site-description">' . $branding_tagline . '</div>';
	}
	echo '<!-- .site-branding --></div>';
}

/* Display header social media icons. -----------------------------------------------*/
function biru_site_social() {
	$nwp_facebook = esc_url( biru_get_option( 'facebook' ) );
	$nwp_twitter = esc_url( biru_get_option( 'twitter' ) );
	$nwp_googleplus = esc_url( biru_get_option( 'googleplus' ) );
	$nwp_tumblr = esc_url( biru_get_option( 'tumblr' ) );
	$nwp_instagram = esc_url( biru_get_option( 'instagram' ) );
	$nwp_youtube = esc_url( biru_get_option( 'youtube' ) );
	$nwp_pinterest = esc_url( biru_get_option( 'pinterest' ) );

	echo '<div id="site-social" class="collapse navbar-collapse navbar-right site-social">';
	echo '<ul class="nav navbar-nav site-social">';
	if ($nwp_facebook)
		echo '<li class="ss-facebook"><a href="' . $nwp_facebook . '" target="_blank" title="' . esc_html__( 'Facebook', 'biru' ) . '"><span class="ti-facebook"></span></a></li>';

	if ($nwp_twitter)
		echo '<li class="ss-twitter"><a href="' . $nwp_twitter . '" target="_blank" title="' . esc_html__( 'Twitter', 'biru' ) . '"><span class="ti-twitter"></span></a></li>';

	if ($nwp_googleplus)
		echo '<li class="ss-google"><a href="' . $nwp_googleplus . '" target="_blank" title="' . esc_html__( 'Google+', 'biru' ) . '"><span class="ti-google"></span></a></li>';

	if ($nwp_tumblr)
		echo '<li class="ss-google"><a href="' . $nwp_tumblr . '" target="_blank" title="' . esc_html__( 'Tumblr', 'biru' ) . '"><span class="ti-tumblr"></span></a></li>';

	if ($nwp_instagram)
		echo '<li class="ss-instagram"><a href="' . $nwp_instagram . '" target="_blank" title="' . esc_html__( 'Instagram', 'biru' ) . '"><span class="ti-instagram"></span></a></li>';

	if ($nwp_youtube)
		echo '<li class="ss-youtube"><a href="' . $nwp_youtube . '" target="_blank" title="' . esc_html__( 'YouTube', 'biru' ) . '"><span class="ti-youtube"></span></a></li>';

	if ($nwp_pinterest)
		echo '<li class="ss-pinterest"><a href="' . $nwp_pinterest . '" target="_blank" title="' . esc_html__( 'Pinterest', 'biru' ) . '"><span class="ti-pinterest"></span></a></li>';

	echo '</ul>';
	echo '</div>';
}

/* Display header search form. ------------------------------------------------------*/
function biru_site_search() {
	echo '<div id="site-search" class="collapse navbar-collapse navbar-right site-search">';
	echo '<div class="search-toggle"><span class="ti-search"></span></div>';
	echo '<div class="search-expand">';
	get_search_form();
	echo '</div>';
	echo '<!-- .site-search --></div>';
}

/*-----------------------------------------------------------------------------------*/
/* Returns the Google fonts stylesheet URL, if available.
/* ----------------------------------------------------------------------------------*/
function biru_fonts_url() {
	$fonts_url = '';

	/* Open Sans. -------------------------------------------------------------------*/
	$font1 = _x( 'on', 'Open Sans font: on or off', 'biru' );

	/* Quicksand. -------------------------------------------------------------------*/
	$font2 = _x( 'on', 'Quicksand font: on or off', 'biru' );

	if ( 'off' !== $font1 || 'off' !== $font2 ) {
		$font_families = array();

		if ( 'off' !== $font1 )
			$font_families[] = 'Open Sans:300,400,600,700,800,400italic,700italic';

		if ( 'off' !== $font2 )
			$font_families[] = 'Quicksand:300,400,700';

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);
		$fonts_url = add_query_arg( $query_args, "//fonts.googleapis.com/css" );
	}

	return $fonts_url;
}

/*-----------------------------------------------------------------------------------*/
/* Enqueue scripts and styles
/* ----------------------------------------------------------------------------------*/

/* Enqueue scripts. -----------------------------------------------------------------*/
function biru_scripts() {
	wp_enqueue_script( 'biru-bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array( 'jquery' ), '', true );
	wp_enqueue_script( 'biru-scripts', get_template_directory_uri() . '/assets/js/scripts.js', false, '1.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'biru_scripts' );

/* Enqueue styles. ------------------------------------------------------------------*/
function biru_styles() {
	wp_enqueue_style( 'biru-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'biru-icons', get_template_directory_uri() . '/assets/css/themify-icons.css' );
	wp_enqueue_style( 'biru-fonts', biru_fonts_url() );
	wp_enqueue_style( 'biru-style', get_stylesheet_uri() );
}
add_action( 'wp_enqueue_scripts', 'biru_styles' );

/*-----------------------------------------------------------------------------------*/
/* Custom functions
/* ----------------------------------------------------------------------------------*/
require_once get_template_directory() . '/includes/neowp-template-tags.php';
require_once get_template_directory() . '/includes/neowp-custom-widgets.php';
require_once get_template_directory() . '/includes/neowp-walker-comment.php';
require_once get_template_directory() . '/includes/neowp-walker-menu.php';
require_once get_template_directory() . '/includes/neowp-customizer.php';