<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Biru
 */

/**
 * Display link pages
 */
function biru_link_pages( $args = array () ) {
    $defaults = array(
        'before'      => '<div class="clearfix text-center"><ul class="pagination">',
        'after'       => '</ul></div>',
        'before_link' => '<li>',
        'after_link'  => '</li>',
        'current_before' => '<li class="active">',
        'current_after' => '</li>',
        'link_before' => '',
        'link_after'  => '',
        'pagelink'    => '%',
        'echo'        => 1
    );

    $r = wp_parse_args( $args, $defaults );
    $r = apply_filters( 'wp_link_pages_args', $r );
    extract( $r, EXTR_SKIP );

    global $page, $numpages, $multipage, $more, $pagenow;

    if ( ! $multipage ) {
        return;
    }

    $output = $before;

    for ( $i = 1; $i < ( $numpages + 1 ); $i++ ) {
        $j       = str_replace( '%', $i, $pagelink );
        $output .= ' ';

        if ( $i != $page || ( ! $more && 1 == $page ) ) {
            $output .= "{$before_link}" . _wp_link_page( $i ) . "{$link_before}{$j}{$link_after}</a>{$after_link}";
        } else {
            $output .= "{$current_before}{$link_before}<a>{$j}</a>{$link_after}{$current_after}";
        }
    }

    print $output . $after;
}
add_filter( 'wp_link_pages', 'biru_link_pages' );

/**
 * Generate custom search form.
 */
function biru_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="searchform" action="' . home_url( '/' ) . '" >
	<div class="form-group">
		<input type="text" class="form-control" name="s" id="s"  value="' . get_search_query() . '" placeholder="'. __( 'type your query and hit enter', 'biru' ) .'" />
	</div>
    </form>';
 
    return $form;
}
add_filter( 'get_search_form', 'biru_search_form' );

if ( ! function_exists( 'biru_post_date' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time.
 */
function biru_post_date() {
	$time_string = '<time class="published updated" datetime="%1$s">%2$s</time>';

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'biru' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	echo '<span class="entry-date"><span class="ti-calendar"></span>' . $posted_on . '</span>'; // WPCS: XSS OK.
}
endif;

if ( ! function_exists( 'biru_post_author' ) ) :
/**
 * Prints HTML with meta information for the current post author.
 */
function biru_post_author() {
	$byline = sprintf(
		esc_html_x( '%s', 'post author', 'biru' ),
		'<a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a>'
	);

	echo '<span class="entry-author author vcard"><span class="ti-user"></span>' . $byline . '</span>'; // WPCS: XSS OK.
}
endif;

if ( ! function_exists( 'biru_post_cat' ) ) :
/**
 * Prints HTML with meta information for the current post categories.
 */
function biru_post_cat() {
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ' / ', 'biru' ) );
		if ( $categories_list && biru_categorized_blog() ) {
			printf( '<span class="entry-categories"><span class="ti-folder"></span>' . esc_html__( '%1$s', 'biru' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}
	}
}
endif;

if ( ! function_exists( 'biru_post_comment' ) ) :
/**
 * Prints HTML with meta information for the current post comment(s).
 */
function biru_post_comment() {
	if ( ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="entry-comments"><span class="ti-comments"></span>';
		/* translators: %s: post title */
		comments_popup_link( 'No Comments', '1 Comment', '% Comments', 'comments-link', 'Comments are off for this post' );
		echo '</span>';
	}
}
endif;

/**
 * Prints HTML with author information of the current post.
 */
function biru_authorbox() {
	echo '<div class="authorbox">';
	echo '<div class="media">';
	echo '<div class="pull-left media-left">' . get_avatar( get_the_author_meta( 'user_email' ), 75 ) . '</div>';
	echo '<div class="media-body">';
	echo '<h4 class="media-heading">' . get_the_author_meta( 'display_name' ) . '</h4>';
	echo '<p>' . the_author_meta( 'description' ) . '</p>';
	echo '</div>';
	echo '</div>';
	echo '</div>';
}

if ( ! function_exists( 'biru_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the tags.
 */
function biru_entry_tags() {
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ' ', 'biru' ) );
		if ( $tags_list ) {
			printf( '<span class="entry-tags">' . esc_html__( '%1$s', 'biru' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 */
function biru_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'biru_categories' ) ) ) {
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			'number'     => 2,
		) );

		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'biru_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Flush out the transients used in biru_categorized_blog.
 */
function biru_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'biru_categories' );
}
add_action( 'edit_category', 'biru_category_transient_flusher' );
add_action( 'save_post',     'biru_category_transient_flusher' );
