<?php
/**
 * Tabber widget
 *
 * @package neowp Widget Pack
 * @version 1.0
 */

/**
 * Adds Biru_Tabs widget.
 */
add_action( 'widgets_init', create_function( '', 'register_widget( "biru_tabs" );' ) );
class Biru_Tabs extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		parent::__construct(
	 		'biru_tabs',
			'Biru Tabs',
			array(
				'description'	=> esc_html__( 'Display a tabbed content widget for your popular posts, recent posts and popular tags.', 'biru' )
			)
		);
	}

	/**
	 * Helper function that holds widget fields
	 * Array is used in update and form functions
	 */
	 private function widget_fields() {
		$fields = array(
			// Other fields
			'tabs_post_count' => array (
				'biru_widgets_name'			=> 'tabs_post_count',
				'biru_widgets_title'			=> esc_html__( 'Posts to Show', 'biru' ),
				'biru_widgets_field_type'		=> 'text'
			),
			'tabs_tag_count' => array (
				'biru_widgets_name'			=> 'tabs_tag_count',
				'biru_widgets_title'			=> esc_html__( 'Tags to Show', 'biru' ),
				'biru_widgets_field_type'		=> 'text'
			),
		);
		
		return $fields;
	 }

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		
		$tabs_post_count	= $instance['tabs_post_count'];
		$tabs_tag_count		= $instance['tabs_tag_count'];

		echo $before_widget;
		?>

		<ul id="widget-tab" class="nav nav-tabs" role="tablist">
			<li role="presentation" class="active"><a href="#widget-tab-popular" aria-controls="widget-tab-popular" role="tab" data-toggle="tab"><?php esc_html_e( 'Popular', 'biru' ); ?></a></li>
			<li role="presentation"><a href="#widget-tab-latest" aria-controls="widget-tab-latest" role="tab" data-toggle="tab"><?php esc_html_e( 'Latest', 'biru' ); ?></a></li>
			<li role="presentation"><a href="#widget-tab-tags" aria-controls="widget-tab-tags" role="tab" data-toggle="tab"><?php esc_html_e( 'Tags', 'biru' ); ?></a></li>
		</ul>
 
		<div class="tab-content">
			<div role="tabpanel" class="tab-pane fade in active" id="widget-tab-popular">
				<ul>
				<?php $popular = new WP_Query('orderby=comment_count&ignore_sticky_posts=1&posts_per_page=' . $tabs_post_count );
					while ($popular->have_posts()) : $popular->the_post(); ?>								
					<li class="media">
						<?php if ( has_post_thumbnail() ) { ?>
						<div class="media-left pull-left entry-thumbnail">
							<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail( 'thumb-small' ); ?></a>
						</div>
						<div class="media-body entry-summary">
							<h4 class="media-heading entry-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php comments_number( esc_html__( 'No Comments', 'biru' ), esc_html__( '1 Comment', 'biru' ), esc_html__( '% Comments', 'biru' ) ); ?></div>
						</div>
						<?php } else { ?>
						<div class="media-body entry-content">
							<h4 class="media-heading entry-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php comments_number( esc_html__( 'No Comments', 'biru' ), esc_html__( '1 Comment', 'biru' ), esc_html__( '% Comments', 'biru' ) ); ?></div>
						</div>
						<?php } ?>
					</li>
				<?php endwhile; wp_reset_query(); ?>
				</ul>
			<!-- #widget-tab-popular --></div>

			<div role="tabpanel" class="tab-pane fade" id="widget-tab-latest">
				<ul>
					<?php $latest = new WP_Query('orderby=post_date&order=DESC&ignore_sticky_posts=1&posts_per_page=' . $tabs_post_count );
					while ( $latest -> have_posts() ) : $latest -> the_post(); ?>
					<li class="media">
						<?php if ( has_post_thumbnail() ) { ?>
						<div class="media-left pull-left entry-thumbnail">
							<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_post_thumbnail( 'thumb-small' ); ?></a>
						</div>
						<div class="media-body entry-summary">
							<h4 class="media-heading entry-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php the_time('F d, Y'); ?></div>
						</div>							
						<?php } else { ?>
						<div class="media-body entry-content">
							<h4 class="media-heading entry-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" rel="bookmark"><?php the_title(); ?></a></h4>
							<div class="entry-meta"><?php the_time('F d, Y'); ?></div>
						</div>							
						<?php } ?>
					</li>
					<?php endwhile; wp_reset_query(); ?>
				</ul>
			<!-- #widget-tab-latest --></div>

			<div role="tabpanel" class="tab-pane fade" id="widget-tab-tags">
				<div class="widget_tag_cloud">
				<?php wp_tag_cloud('smallest=1&largest=1&unit=em&orderby=count&order=DESC&number=' . $tabs_tag_count ); ?>
				</div>
			<!-- #widget-tab-tags --></div>
		</div>

	<?php
		echo $after_widget;
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param	array	$new_instance	Values just sent to be saved.
	 * @param	array	$old_instance	Previously saved values from database.
	 *
	 * @uses	biru_widgets_show_widget_field()		defined in widget-fields.php
	 *
	 * @return	array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$widget_fields = $this->widget_fields();

		// Loop through fields
		foreach( $widget_fields as $widget_field ) {
			extract( $widget_field );
	
			// Use helper function to get updated field values
			$instance[$biru_widgets_name] = biru_widgets_updated_field_value( $widget_field, $new_instance[$biru_widgets_name] );
			echo $instance[$biru_widgets_name];
		}
				
		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 *
	 * @uses	biru_widgets_show_widget_field()		defined in widget-fields.php
	 */
	public function form( $instance ) {
		$widget_fields = $this->widget_fields();

		// Loop through fields
		foreach( $widget_fields as $widget_field ) {
		
			// Make array elements available as variables
			extract( $widget_field );
			$biru_widgets_field_value = isset( $instance[$biru_widgets_name] ) ? esc_attr( $instance[$biru_widgets_name] ) : '';
			biru_widgets_show_widget_field( $this, $widget_field, $biru_widgets_field_value );
		
		}	
	}

}